==> plugin-api-1.2.1-sources.jar: com/xebialabs/deployit/ci/artifact/Folder.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of Xebialabs Software and Documentation is subject to the Personal
 * License Agreement.
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * ‚ÄúDocumentation‚Äù means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the Xebialabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci.artifact;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.ConfigurationItem;

/**
 * Represents a directory of files.
 */
@SuppressWarnings("serial")
@ConfigurationItem
public abstract class Folder extends DeployableArtifact {

	public List<File> getFiles() {
		List<File> files = new ArrayList<File>();
		File folderLocation = new File(getLocation());
		if (folderLocation.exists() && folderLocation.isDirectory() && folderLocation.canRead()) {
			File[] allFiles = folderLocation.listFiles();
			if (allFiles != null && allFiles.length > 0) {
				for (int i = 0; i < allFiles.length; i++) {
					files.add(allFiles[i]);
				}
			}
		}
		return files;
	}

}

==> plugin-api-1.2.2-sources.jar: com/xebialabs/deployit/ci/artifact/Folder.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.ci.artifact;

import java.io.File;
import java.util.ArrayList;
import java.util.List;

import com.xebialabs.deployit.ConfigurationItem;

/**
 * Represents a directory of files.
 */
@SuppressWarnings("serial")
@ConfigurationItem
public abstract class Folder extends DeployableArtifact {

	public List<File> getFiles() {
		List<File> files = new ArrayList<File>();
		File folderLocation = new File(getLocation());
		if (folderLocation.exists() && folderLocation.isDirectory() && folderLocation.canRead()) {
			File[] allFiles = folderLocation.listFiles();
			if (allFiles != null && allFiles.length > 0) {
				for (int i = 0; i < allFiles.length; i++) {
					files.add(allFiles[i]);
				}
			}
		}
		return files;
	}
	
	@Override
	public boolean validate() {
		File folderLocation = new File(getLocation());
		return (folderLocation.exists() && folderLocation.isDirectory() && folderLocation.canRead()) ;
	}
	
	@Override
	public String getValidationError() {
		return "artifact file does not exist, is unreadable, or not a directory";
	}

}
